@@ -1,5 +1,5 @@
 from .bin_2d import bin_2d
-from .bin_3d import bin_3d
+# from .bin_3d import bin_3d
 from .fft_image_filter import remove_horizontal_vertical_edges
 from .fill_and_label_rois import fill_and_label_rois
 from .four_color_theorem.four_color_theorem_to_unique_values import four_color_to_unique
@@ -9,10 +9,11 @@ from .normalize import normalize
 from .rgb2gray import rgb2gray
 from .rgb2labels import rgb2labels
 from .sum_pool_3d import sum_pool_3d
+from .remove_small_areas_fill_regions import remove_small_areas_fill_regions
 
 __all__ = [
     "bin_2d",
-    "bin_3d",
+    # "bin_3d",
     "sum_pool_3d",
     "normalize",
     "kmeans_threshold",
@@ -22,4 +23,5 @@ __all__ = [
     "fill_and_label_rois",
     "four_color_theorem",
     "four_color_to_unique",
+    "remove_small_areas_fill_regions"
 ]
