@@ -23,11 +23,21 @@ def fill_and_label_rois(curr_nuclei):
 if __name__ == "__main__":
     
     from pathlib import Path
+    import tifffile
     
+    import matplotlib.pylab as plt
+    import matplotlib as mpl
+    mpl.rcParams['figure.dpi'] = 300
     
     HERE = Path(__file__).absolute().resolve()
     print(HERE)
     path_mask = Path(r"../../examples/example_data/redox_ratio/HPDE_2DG_10n_mask_cells.tiff")
     
+    mask = tifffile.imread(path_mask)
+    
+    plt.imshow(mask)
+    
+    
+    
     
     
\ No newline at end of file
