@@ -10,8 +10,8 @@ from .read_asc import read_asc
 
 def load_image(path: Union[str, pathlib.PurePath]) -> np.ndarray:
     """
-    Detects the extension and loads image accordingly
-    if its a tif/tiff or an asc
+    Detects the extension and loads image into a numpy array 
+    if it's a tif/tiff or an asc file.
 
     Parameters
     ----------
@@ -21,7 +21,7 @@ def load_image(path: Union[str, pathlib.PurePath]) -> np.ndarray:
     Returns
     -------
     np.ndarray
-        array containig image.
+        ndarray with the image data.
 
     """
     if not isinstance(path, pathlib.PurePath):
