@@ -1,5 +1,6 @@
 from .image_viewers import compare_images, compare_orig_mask_gt_pred, image_show
 from .umap_tsne_pca import compute_pca, compute_tsne, compute_umap
+from .mask_to_outline import mask_to_outlines
 
 __all__ = [
     "image_show",
@@ -8,4 +9,5 @@ __all__ = [
     "compute_pca",
     "compute_tsne",
     "compute_umap",
+    "mask_to_outlines"
 ]
